@@ -1,5 +1,5 @@
 /*
- *  $Id: arrows.c,v 1.40 2011/10/16 21:19:58 tom Exp $
+ *  $Id: arrows.c,v 1.41 2011/10/20 23:37:17 tom Exp $
  *
  *  arrows.c -- draw arrows to indicate end-of-range for lists
  *
@@ -124,11 +124,11 @@ dlg_draw_arrows2(WINDOW *win,
     if (draw_top) {
 	(void) wmove(win, top, x);
 	if (top_arrow) {
-	    wattrset(win, merge_colors(uarrow_attr, attr));
+	    (void) wattrset(win, merge_colors(uarrow_attr, attr));
 	    (void) add_acs(win, ACS_UARROW);
 	    (void) waddstr(win, "(-)");
 	} else {
-	    wattrset(win, attr);
+	    (void) wattrset(win, attr);
 	    (void) whline(win, dlg_boxchar(ACS_HLINE), ON_LEFT);
 	}
     }
@@ -136,11 +136,11 @@ dlg_draw_arrows2(WINDOW *win,
 
     (void) wmove(win, bottom, x);
     if (bottom_arrow) {
-	wattrset(win, merge_colors(darrow_attr, attr));
+	(void) wattrset(win, merge_colors(darrow_attr, attr));
 	(void) add_acs(win, ACS_DARROW);
 	(void) waddstr(win, "(+)");
     } else {
-	wattrset(win, borderattr);
+	(void) wattrset(win, borderattr);
 	(void) whline(win, dlg_boxchar(ACS_HLINE), ON_LEFT);
     }
     mouse_mkbutton(bottom, x - 1, 6, KEY_NPAGE);
@@ -148,7 +148,7 @@ dlg_draw_arrows2(WINDOW *win,
     (void) wmove(win, cur_y, cur_x);
     wrefresh(win);
 
-    wattrset(win, save);
+    (void) wattrset(win, save);
 }
 
 void
@@ -187,12 +187,12 @@ dlg_draw_scrollbar(WINDOW *win,
 	else if (percent > 100)
 	    percent = 100;
 
-	wattrset(win, position_indicator_attr);
+	(void) wattrset(win, position_indicator_attr);
 	(void) sprintf(buffer, "%d%%", percent);
 	(void) wmove(win, bottom, right - 7);
 	(void) waddstr(win, buffer);
 	if ((len = dlg_count_columns(buffer)) < 4) {
-	    wattrset(win, border_attr);
+	    (void) wattrset(win, border_attr);
 	    whline(win, dlg_boxchar(ACS_HLINE), 4 - len);
 	}
     }
@@ -212,7 +212,7 @@ dlg_draw_scrollbar(WINDOW *win,
 	    if (bar_high < all_high) {
 		wmove(win, top + 1, right);
 
-		wattrset(win, save);
+		(void) wattrset(win, save);
 		wvline(win, ACS_VLINE | A_REVERSE, all_high);
 
 		bar_y = BARSIZE(this_data);
@@ -221,7 +221,7 @@ dlg_draw_scrollbar(WINDOW *win,
 
 		wmove(win, top + 1 + bar_y, right);
 
-		wattrset(win, position_indicator_attr);
+		(void) wattrset(win, position_indicator_attr);
 		wattron(win, A_REVERSE);
 		wvline(win, ACS_BLOCK, bar_high);
 	    }
@@ -236,7 +236,7 @@ dlg_draw_scrollbar(WINDOW *win,
 		     attr,
 		     borderattr);
 
-    wattrset(win, save);
+    (void) wattrset(win, save);
     wmove(win, oldy, oldx);
 }
 
