@@ -1,5 +1,5 @@
 /*
- * $Id: calendar.c,v 1.64 2011/10/15 13:10:41 tom Exp $
+ * $Id: calendar.c,v 1.65 2011/10/20 23:51:07 tom Exp $
  *
  *  calendar.c -- implements the calendar box
  *
@@ -232,7 +232,7 @@ draw_day(BOX * data, struct tm *current)
 		  menubox_border_attr,
 		  menubox_border2_attr);
 
-    wattrset(data->window, menubox_attr);	/* daynames headline */
+    (void) wattrset(data->window, menubox_attr);	/* daynames headline */
     for (x = 0; x < 7; x++) {
 	mvwprintw(data->window,
 		  0, (x + 1) * cell_wide, "%*.*s ",
@@ -248,7 +248,7 @@ draw_day(BOX * data, struct tm *current)
     week = (current->tm_yday + 6 + mday - current->tm_mday) / 7;
 
     for (y = 1; mday < last; y++) {
-	wattrset(data->window, menubox_attr);	/* weeknumbers headline */
+	(void) wattrset(data->window, menubox_attr);	/* weeknumbers headline */
 	mvwprintw(data->window,
 		  y, 0,
 		  "%*d ",
@@ -259,9 +259,9 @@ draw_day(BOX * data, struct tm *current)
 	    ++mday;
 	    if (wmove(data->window, y, this_x) == ERR)
 		continue;
-	    wattrset(data->window, item_attr);	/* not selected days */
+	    (void) wattrset(data->window, item_attr);	/* not selected days */
 	    if (mday == day) {
-		wattrset(data->window, item_selected_attr);	/* selected day */
+		(void) wattrset(data->window, item_selected_attr);	/* selected day */
 		save_y = y;
 		save_x = this_x;
 	    }
@@ -296,7 +296,7 @@ draw_month(BOX * data, struct tm *current)
 
     month = current->tm_mon + 1;
 
-    wattrset(data->parent, dialog_attr);	/* Headline "Month" */
+    (void) wattrset(data->parent, dialog_attr);		/* Headline "Month" */
     (void) mvwprintw(data->parent, data->y - 2, data->x - 1, _("Month"));
     dlg_draw_box2(data->parent,
 		  data->y - 1, data->x - 1,
@@ -304,7 +304,7 @@ draw_month(BOX * data, struct tm *current)
 		  menubox_attr,
 		  menubox_border_attr,
 		  menubox_border2_attr);
-    wattrset(data->window, item_attr);	/* color the month selection */
+    (void) wattrset(data->window, item_attr);	/* color the month selection */
     mvwprintw(data->window, 0, 0, "%s", nameOfMonth(month - 1));
     wmove(data->window, 0, 0);
     return 0;
@@ -318,7 +318,7 @@ draw_year(BOX * data, struct tm *current)
 {
     int year = current->tm_year + 1900;
 
-    wattrset(data->parent, dialog_attr);	/* Headline "Year" */
+    (void) wattrset(data->parent, dialog_attr);		/* Headline "Year" */
     (void) mvwprintw(data->parent, data->y - 2, data->x - 1, _("Year"));
     dlg_draw_box2(data->parent,
 		  data->y - 1, data->x - 1,
@@ -326,7 +326,7 @@ draw_year(BOX * data, struct tm *current)
 		  menubox_attr,
 		  menubox_border_attr,
 		  menubox_border2_attr);
-    wattrset(data->window, item_attr);	/* color the year selection */
+    (void) wattrset(data->window, item_attr);	/* color the year selection */
     mvwprintw(data->window, 0, 0, "%4d", year);
     wmove(data->window, 0, 0);
     return 0;
@@ -501,7 +501,7 @@ dialog_calendar(const char *title,
     dlg_draw_bottom_box2(dialog, border_attr, border2_attr, dialog_attr);
     dlg_draw_title(dialog, title);
 
-    wattrset(dialog, dialog_attr);	/* text mainbox */
+    (void) wattrset(dialog, dialog_attr);	/* text mainbox */
     dlg_print_autowrap(dialog, prompt, height, width);
 
     /* compute positions of day, month and year boxes */
