@@ -1,5 +1,5 @@
 /*
- *  $Id: util.c,v 1.239 2011/10/18 22:25:13 tom Exp $
+ *  $Id: util.c,v 1.242 2011/10/20 23:42:10 tom Exp $
  *
  *  util.c -- miscellaneous utilities for dialog
  *
@@ -159,18 +159,24 @@ add_subwindow(WINDOW *parent, WINDOW *child)
 static void
 del_subwindows(WINDOW *parent)
 {
-    DIALOG_WINDOWS *p, *q;
+    DIALOG_WINDOWS *p = dialog_state.all_subwindows;
+    DIALOG_WINDOWS *q = 0;
+    DIALOG_WINDOWS *r;
 
-    for (p = dialog_state.all_subwindows, q = 0; p != 0; q = p, p = p->next) {
+    while (p != 0) {
 	if (p->normal == parent) {
 	    delwin(p->shadow);
+	    r = p->next;
 	    if (q == 0) {
-		dialog_state.all_subwindows = p->next;
+		dialog_state.all_subwindows = r;
 	    } else {
-		q->next = p->next;
+		q->next = r;
 	    }
 	    free(p);
-	    continue;
+	    p = r;
+	} else {
+	    q = p;
+	    p = p->next;
 	}
     }
 }
@@ -309,7 +315,7 @@ init_dialog(FILE *input, FILE *output)
      */
     dialog_state.pipe_input = stdin;
     if (fileno(input) != fileno(stdin)) {
-	if ((fd1 = dup(fileno(input))) >= 0
+	if (dup(fileno(input)) >= 0
 	    && (fd2 = dup(fileno(stdin))) >= 0) {
 	    (void) dup2(fileno(input), fileno(stdin));
 	    dialog_state.pipe_input = fdopen(fd2, "r");
@@ -318,7 +324,7 @@ init_dialog(FILE *input, FILE *output)
 	} else
 	    dlg_exiterr("cannot open tty-input");
     } else if (!isatty(fileno(stdin))) {
-	if ((fd1 = open_terminal(&device, O_RDONLY)) >= 0
+	if (open_terminal(&device, O_RDONLY) >= 0
 	    && (fd2 = dup(fileno(stdin))) >= 0) {
 	    dialog_state.pipe_input = fdopen(fd2, "r");
 	    if (freopen(device, "r", stdin) == 0)
@@ -1183,23 +1189,24 @@ real_auto_size(const char *title,
 	high = SLINES - y;
     }
 
-    if (*width > 0) {
-	wide = *width;
-    } else if (prompt != 0) {
-	wide = MAX(title_length, mincols);
-	if (strchr(prompt, '\n') == 0) {
-	    double val = dialog_state.aspect_ratio * dlg_count_real_columns(prompt);
-	    double xxx = sqrt(val);
-	    int tmp = (int) xxx;
-	    wide = MAX(wide, tmp);
-	    wide = MAX(wide, longest_word(prompt));
-	    justify_text((WINDOW *) 0, prompt, high, wide, height, width);
+    if (*width <= 0) {
+	if (prompt != 0) {
+	    wide = MAX(title_length, mincols);
+	    if (strchr(prompt, '\n') == 0) {
+		double val = (dialog_state.aspect_ratio *
+			      dlg_count_real_columns(prompt));
+		double xxx = sqrt(val);
+		int tmp = (int) xxx;
+		wide = MAX(wide, tmp);
+		wide = MAX(wide, longest_word(prompt));
+		justify_text((WINDOW *) 0, prompt, high, wide, height, width);
+	    } else {
+		auto_size_preformatted(prompt, height, width);
+	    }
 	} else {
-	    auto_size_preformatted(prompt, height, width);
+	    wide = SCOLS - x;
+	    justify_text((WINDOW *) 0, prompt, high, wide, height, width);
 	}
-    } else {
-	wide = SCOLS - x;
-	justify_text((WINDOW *) 0, prompt, high, wide, height, width);
     }
 
     if (*width < title_length) {
